@@ -278,7 +278,7 @@ class Normalize(object):
         norm_type (str): type in ['mean_std', 'none']
     """
 
-    def __init__(self, mean, std, is_scale=True, norm_type='mean_std'):
+    def __init__(self, mean=(0.485, 0.456, 0.406), std=(0.229, 0.224, 0.225), is_scale=True, norm_type='mean_std'):
         self.mean = mean
         self.std = std
         self.is_scale = is_scale
