@@ -4,10 +4,11 @@ import paddle
 
 
 # 基于Paddle-Inference封装的通用Paddle推理器
-class PaddlePredict(object):
+class Model(object):
 
-    def __init__(self, model_path, use_paddle_inference=True, gpu_memory_pool_init_size_mb=100, gpu_device_id=0, cpu_num_threads=1):
+    def __init__(self, model_path, use_paddle_inference=True, output_lod=False, gpu_memory_pool_init_size_mb=100, gpu_device_id=0, cpu_num_threads=1):
         self.use_paddle_inference = use_paddle_inference
+        self.output_lod = output_lod
         if self.use_paddle_inference:
             if os.path.exists(model_path + '.pdmodel') and os.path.exists(model_path + '.pdiparams'):
                 config = paddle.inference.Config(model_path + '.pdmodel', model_path + '.pdiparams')
@@ -38,21 +39,24 @@ class PaddlePredict(object):
             self.model = paddle.jit.load(model_path)
             self.model.eval()
 
-    def predict(self, input_list):
+    def predict(self, input_list: list) -> list:
         if self.use_paddle_inference:
             for i in range(len(input_list)):
                 self.input_handles[i].copy_from_cpu(input_list[i])
 
             self.predictor.run()
 
-            output_data = []
+            output_list = []
             for output_handle in self.output_handles:
                 value = output_handle.copy_to_cpu()
-                lod = output_handle.lod()
-                output_data.append({'value': value, 'lod': lod})
+                if self.output_lod:
+                    lod = output_handle.lod()
+                    output_list.append({'value': value, 'lod': lod})
+                else:
+                    output_list.append(value)
             self.predictor.clear_intermediate_tensor()  # 释放中间Tensor
             self.predictor.try_shrink_memory()  # 释放内存池中的所有临时Tensor
-            return output_data
+            return output_list
         else:
             results = self.model(paddle.to_tensor(input_list[0]))
 
@@ -60,7 +64,7 @@ class PaddlePredict(object):
             if not isinstance(results, list):
                 results = [results]
 
-            output_data = []
+            output_list = []
             for result in results:
-                output_data.append({'value': result.numpy()})
-            return output_data
+                output_list.append(result.numpy())
+            return output_list
